@@ -395,10 +395,10 @@ bool BugzillaInformationPage::showNextPage()
                                     "will probably waste developers' time. Can you tell us more?");
 
             KGuiItem yesItem = KStandardGuiItem::yes();
-            yesItem.setText("Yes, let me add more information");
+            yesItem.setText(i18n("Yes, let me add more information"));
 
             KGuiItem noItem = KStandardGuiItem::no();
-            noItem.setText("No, I cannot add any other information");
+            noItem.setText(i18n("No, I cannot add any other information"));
 
             if (KMessageBox::warningYesNo(this, message,
                                            i18nc("@title:window","We need more information"),
