@@ -26,7 +26,6 @@
 
 #include <kurl.h>
 #include <klocale.h>
-#include <kapplication.h>
 #include <kio/netaccess.h>
 #include <kio/job.h>
 #include <kio/copyjob.h>
@@ -208,6 +207,14 @@ void TestTrash::initTestCase()
     removeDirRecursive( m_trashDir );
 }
 
+void TestTrash::cleanupTestCase()
+{
+    // Clean up
+    removeDirRecursive( homeTmpDir() );
+    removeDirRecursive( otherTmpDir() );
+    removeDirRecursive( m_trashDir );
+}
+
 void TestTrash::urlTestFile()
 {
     const KUrl url = TrashImpl::makeURL(1, QString::fromLatin1("fileId"), QString());
